@@ -222,7 +222,7 @@ def refreshAccessToken(identity, contextList, deltaMinutes=0, headers=None, data
     return retrieveApiInstance(apiInstance=apiInstance).sessionManager.encode({
             JwtConstant.KW_IAT: timeNow,
             JwtConstant.KW_NFB: timeNow,
-            JwtConstant.KW_JTI: getJti(apiInstance=apiInstance),
+            JwtConstant.KW_JTI: getNewJti(),
             JwtConstant.KW_EXPIRATION: UtcDateTimeUtil.plusMinutes(timeNow, minutes=deltaMinutes),
             JwtConstant.KW_IDENTITY: identity,
             JwtConstant.KW_FRESH: False,
@@ -256,7 +256,7 @@ def patchAccessToken(newContextList=None, headers=None, data=None, apiInstance=N
     return apiInstance.sessionManager.encode({
             JwtConstant.KW_IAT: getIat(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_NFB: getNfb(rawJwt=rawJwt, apiInstance=apiInstance),
-            JwtConstant.KW_JTI: getJti(rawJwt=rawJwt, apiInstance=apiInstance),
+            JwtConstant.KW_JTI: getNewJti(),
             JwtConstant.KW_EXPIRATION: getExpiration(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_IDENTITY: getIdentity(rawJwt=rawJwt, apiInstance=apiInstance),
             JwtConstant.KW_FRESH: False,
@@ -272,11 +272,12 @@ def getCurrentSession(sessionClass=None, apiInstance=None):
     rawJwt = getJwtBody(apiInstance=apiInstance)
     identity = getIdentity(rawJwt=rawJwt, apiInstance=apiInstance)
     context = getContext(rawJwt=rawJwt, apiInstance=apiInstance)
+    data = getData(rawJwt=rawJwt, apiInstance=apiInstance)
     if ObjectHelper.isNone(sessionClass):
         return {
             JwtConstant.KW_IDENTITY: identity,
             JwtConstant.KW_CONTEXT: context,
-            JwtConstant.KW_DATA: getData(rawJwt=rawJwt, apiInstance=apiInstance)
+            JwtConstant.KW_DATA: data
         }
     else:
         currentSession = sessionClass()
@@ -284,7 +285,6 @@ def getCurrentSession(sessionClass=None, apiInstance=None):
             JwtConstant.KW_IDENTITY: identity,
             JwtConstant.KW_CONTEXT: context
         }
-        data = getData(rawJwt=rawJwt, apiInstance=apiInstance)
         for attributeName in data:
             if ReflectionHelper.hasAttributeOrMethod(currentSession, attributeName):
                 ReflectionHelper.setAttributeOrMethod(currentSession, attributeName, data.get(attributeName))
@@ -305,31 +305,13 @@ def addSessionManager(apiInstance, appInstance):
         log.warning(addSessionManager, 'Not possible to add SessionManager', exception=exception)
 
 def retrieveApiInstance(apiInstance=None, arguments=None):
-    if FlaskUtil.isApiInstance(apiInstance):
-        return apiInstance
-    if FlaskUtil.isApiInstance(API_INSTANCE_HOLDER.get(KEY_API_INSTANCE)):
-        return API_INSTANCE_HOLDER.get(KEY_API_INSTANCE)
-    if ObjectHelper.isNone(apiInstance) and ObjectHelper.isNotNone(arguments):
-        try:
-            apiInstance = arguments[0].globals.api
-        except Exception as exception:
-            log.log(retrieveApiInstance, f'''Not possible to retrieve api instance. args: {arguments}''', exception=exception, muteStackTrace=True)
-            log.warning(retrieveApiInstance, f'''Not possible to retrieve api instance by arguments. Going for another approach''')
-    if not FlaskUtil.isApiInstance(apiInstance):
-        log.warning(retrieveApiInstance, f'''Not possible to retrieve api instance. Going for a slower approach''')
-        apiInstance = FlaskUtil.getApi()
-    if ObjectHelper.isNone(apiInstance):
-        raiseUnretrievedApiInstance()
+    apiInstance = FlaskUtil.retrieveApiInstance(apiInstance=apiInstance, arguments=arguments)
     if ObjectHelper.isNone(apiInstance.sessionManager):
         raise Exception('There is no session manager')
-    API_INSTANCE_HOLDER[KEY_API_INSTANCE] = apiInstance
     return apiInstance
 
 def raiseSessionContextCannotBeNone():
     raise Exception('Context cannot be None')
 
-def raiseUnretrievedApiInstance():
-    raise Exception('Not possible to retrieve api instance')
-
 def getNewJti():
     return f"{int(f'{time.time()}'.replace('.', '')) + int(f'{time.time()}'.replace('.', ''))}"
